==> GridCal-5.1.0.tar.gz: GridCal-5.1.0/GridCal/Gui/WindPowerWizard/icons_rc.py <==
# Resource object code (Python 3)
# Created by: object code
# Created by: The Resource Compiler for Qt version 6.5.1
# WARNING! All changes made in this file will be lost!

from PySide6 import QtCore

qt_resource_data = b"\
\x00\x00\x1b\xfb\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<svg\x0a   wi\
dth=\x2248\x22\x0a   heig\
ht=\x2248\x22\x0a   viewB\
ox=\x220 0 48 48\x22\x0a \
  version=\x221.1\x22\x0a\
   id=\x22svg6\x22\x0a   \
sodipodi:docname\
=\x22wind_power.svg\
\x22\x0a   inkscape:ve\
rsion=\x221.1.2 (0a\
00cf5339, 2022-0\
2-04)\x22\x0a   xmlns:\
inkscape=\x22http:/\
/www.inkscape.or\
g/namespaces/ink\
scape\x22\x0a   xmlns:\
sodipodi=\x22http:/\
/sodipodi.source\
forge.net/DTD/so\
dipodi-0.dtd\x22\x0a  \
 xmlns=\x22http://w\
ww.w3.org/2000/s\
vg\x22\x0a   xmlns:svg\
=\x22http://www.w3.\
org/2000/svg\x22\x0a  \
 xmlns:rdf=\x22http\
://www.w3.org/19\
99/02/22-rdf-syn\
tax-ns#\x22\x0a   xmln\
s:cc=\x22http://cre\
ativecommons.org\
/ns#\x22\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22>\x0a  <metadat\
a\x0a     id=\x22metad\
ata12\x22>\x0a    <rdf\
:RDF>\x0a      <cc:\
Work\x0a         rd\
f:about=\x22\x22>\x0a    \
    <dc:format>i\
mage/svg+xml</dc\
:format>\x0a       \
 <dc:type\x0a      \
     rdf:resourc\
e=\x22http://purl.o\
rg/dc/dcmitype/S\
tillImage\x22 />\x0a  \
    </cc:Work>\x0a \
   </rdf:RDF>\x0a  \
</metadata>\x0a  <d\
efs\x0a     id=\x22def\
s10\x22>\x0a    <marke\
r\x0a       inkscap\
e:stockid=\x22Arrow\
1Lstart\x22\x0a       \
orient=\x22auto\x22\x0a  \
     refY=\x220.0\x22\x0a\
       refX=\x220.0\
\x22\x0a       id=\x22Arr\
ow1Lstart\x22\x0a     \
  style=\x22overflo\
w:visible\x22\x0a     \
  inkscape:issto\
ck=\x22true\x22>\x0a     \
 <path\x0a         \
id=\x22path4598\x22\x0a  \
       d=\x22M 0.0,\
0.0 L 5.0,-5.0 L\
 -12.5,0.0 L 5.0\
,5.0 L 0.0,0.0 z\
 \x22\x0a         styl\
e=\x22fill-rule:eve\
nodd;stroke:#000\
000;stroke-width\
:1.0pt\x22\x0a        \
 transform=\x22scal\
e(0.8) translate\
(12.5,0)\x22 />\x0a   \
 </marker>\x0a  </d\
efs>\x0a  <sodipodi\
:namedview\x0a     \
pagecolor=\x22#ffff\
ff\x22\x0a     borderc\
olor=\x22#666666\x22\x0a \
    borderopacit\
y=\x221\x22\x0a     objec\
ttolerance=\x2210\x22\x0a\
     gridtoleran\
ce=\x2210\x22\x0a     gui\
detolerance=\x2210\x22\
\x0a     inkscape:p\
ageopacity=\x220\x22\x0a \
    inkscape:pag\
eshadow=\x222\x22\x0a    \
 inkscape:window\
-width=\x222495\x22\x0a  \
   inkscape:wind\
ow-height=\x221016\x22\
\x0a     id=\x22namedv\
iew8\x22\x0a     showg\
rid=\x22false\x22\x0a    \
 inkscape:zoom=\x22\
3.0052038\x22\x0a     \
inkscape:cx=\x2266.\
21847\x22\x0a     inks\
cape:cy=\x22-22.793\
795\x22\x0a     inksca\
pe:window-x=\x2265\x22\
\x0a     inkscape:w\
indow-y=\x2227\x22\x0a   \
  inkscape:windo\
w-maximized=\x221\x22\x0a\
     inkscape:cu\
rrent-layer=\x22svg\
6\x22\x0a     inkscape\
:pagecheckerboar\
d=\x220\x22 />\x0a  <path\
\x0a     style=\x22fil\
l:#37c8ab;fill-o\
pacity:1;stroke-\
width:0.066147\x22\x0a\
     d=\x22M 4.8016\
926,44.487649 C \
2.4893281,44.458\
362 2.1648285,44\
.441422 1.979776\
2,44.340138 1.64\
58014,44.157407 \
1.4942949,43.916\
69 1.4945821,43.\
569206 c 0,-0.40\
9206 0.1916083,-\
0.710501 0.55242\
93,-0.870095 0.2\
665959,-0.117937\
 0.5131888,-0.12\
7024 3.9174436,-\
0.144328 l 3.632\
9018,-0.01847 v \
-5.409122 -5.409\
122 l -0.1984511\
,0.04072 c -0.93\
13392,0.191078 -\
3.381189,0.80561\
7 -3.9674033,0.9\
95225 -0.7743774\
,0.250464 -1.066\
6233,0.262002 -1\
.299482,0.05129 \
-0.2374048,-0.21\
4856 -0.1029823,\
-0.984423 0.2002\
7,-1.146735 0.07\
5418,-0.04034 0.\
3383773,-0.13548\
1 0.5843959,-0.2\
11373 0.2459708,\
-0.0759 0.566307\
2,-0.192575 0.71\
18319,-0.259283 \
1.0177639,-0.466\
56 2.4351586,-1.\
045491 2.7120432\
,-1.107716 0.181\
8939,-0.04087 0.\
4946214,-0.09272\
 0.6949392,-0.11\
5195 l 0.3641707\
,-0.04087 0.0988\
19,-0.308593 c 0\
.072499,-0.22625\
 0.1525115,-0.33\
5415 0.2998545,-\
0.409101 0.19897\
8,-0.0995 0.2001\
74,-0.10327 0.12\
0162,-0.379546 -\
0.188258,-0.6502\
63 -0.293394,-1.\
935168 -0.294686\
,-3.601539 0,-2.\
24132 0.05915,-2\
.507547 0.594254\
2,-2.597949 0.30\
9282,-0.05226 0.\
588702,0.05141 0\
.661919,0.245569\
 0.117195,0.3107\
18 0.579276,4.17\
9943 0.645746,5.\
406892 0.03876,0\
.717823 0.06211,\
0.839162 0.17892\
7,0.933756 0.103\
46,0.08378 0.140\
595,0.208017 0.1\
61843,0.541528 0\
.02728,0.430588 \
0.02871,0.433014\
 0.247358,0.4740\
34 0.266979,0.05\
009 4.237397,2.0\
4832 4.442022,2.\
235573 0.338712,\
0.310029 0.21816\
7,0.900694 -0.21\
2856,1.04295 -0.\
135092,0.0446 -0\
.353786,0.06625 \
-0.48596,0.04813\
 -0.39006,-0.053\
45 -2.817179,-1.\
046697 -3.936298\
,-1.610826 -0.40\
9967,-0.206659 -\
0.574538,-0.2634\
38 -0.545682,-0.\
188249 0.02249,0\
.05921 0.04115,2\
.508844 0.04115,\
5.443615 l 4.8e-\
5,5.335958 2.563\
168,0.01857 c 1.\
409738,0.01024 3\
.433829,-4.79e-4\
 4.497964,-0.024\
12 l 1.934794,-0\
.04269 v -8.1895\
11 -8.189515 l -\
0.227164,-0.0749\
6 c -0.203859,-0\
.06729 -0.58698,\
-0.417557 -0.740\
161,-0.67673 -0.\
03206,-0.05394 -\
0.251426,-0.1652\
03 -0.487922,-0.\
247244 -3.345537\
,-1.160662 -5.93\
5122,-2.115981 -\
6.191907,-2.2842\
12 -0.238219,-0.\
156091 -0.446241\
,-0.649339 -0.39\
3171,-0.932263 0\
.06513,-0.347091\
 0.318996,-0.598\
786 0.694844,-0.\
688957 0.38001,-\
0.09116 0.30842,\
-0.108376 2.6159\
99,0.629125 2.41\
104,0.978701 3.2\
87204,1.308684 4\
.413166,1.668538\
 l 0.340052,0.04\
159 c 0.286503,0\
.03503 0.355701,\
0.02168 0.439302\
,-0.08475 0.6227\
27,-0.792725 0.7\
63514,-0.970092 \
0.792753,-0.9984\
45 0.08197,-0.07\
957 1.403709,-1.\
538988 1.85708,-\
2.050554 0.69532\
2,-0.78459 1.745\
339,-2.038198 2.\
691035,-3.212771\
 0.889658,-1.104\
978 1.116774,-1.\
275665 1.581534,\
-1.188474 0.3663\
72,0.06873 0.602\
964,0.210812 0.7\
16426,0.430267 0\
.131647,0.254584\
 0.127627,0.6834\
73 -0.0091,0.948\
04 -0.155096,0.3\
00616 -0.830558,\
1.196141 -2.1169\
28,2.806684 -0.6\
12821,0.767252 -\
1.530953,1.92331\
5 -2.040313,2.56\
9017 -0.509313,0\
.645707 -0.99053\
5,1.237376 -1.06\
9351,1.314824 -0\
.126096,0.12388 \
-0.137772,0.1842\
72 -0.09724,0.50\
2144 0.06207,0.4\
87103 -0.01962,0\
.974398 -0.19467\
1,1.160714 l -0.\
14251,0.151674 0\
.121311,0.534761\
 c 0.07197,0.317\
461 0.02536,0.12\
2096 1.674659,4.\
618135 0.633542,\
1.727045 1.33652\
1,3.388401 1.400\
741,3.512664 0.3\
6063,0.697939 -0\
.357375,1.370703\
 -0.824816,0.737\
544 -0.425184,-0\
.575931 -1.38739\
,-2.765683 -3.41\
4974,-6.4171 -0.\
828644,-1.49222 \
0.110161,-2.3902\
38 0.107529,-2.2\
95817 -0.0048,0.\
115123 0.69336,3\
.902628 0.690345\
,9.181342 l -0.0\
048,6.787626 5.4\
07528,0.01259 c \
2.974141,0.0069 \
6.070119,-0.0083\
 6.879956,-0.033\
83 l 1.47238,-0.\
04642 v -5.47085\
9 c 0,-3.008969 \
-0.02106,-5.4899\
57 -0.0445,-5.51\
3301 -0.02345,-0\
.02335 -0.09585,\
0.04546 -0.16122\
1,0.152856 -0.19\
0652,0.313513 -0\
.854486,0.574031\
 -2.87695,1.1290\
54 -1.400024,0.3\
84207 -1.674324,\
0.406842 -1.8727\
76,0.154555 -0.2\
22474,-0.282862 \
-0.162417,-0.776\
033 0.121789,-0.\
999756 0.117483,\
-0.09249 1.05159\
7,-0.553238 2.79\
9043,-1.380581 1\
.135437,-0.53758\
 1.738306,-0.752\
723 2.109272,-0.\
752723 0.146625,\
0 0.172084,-0.02\
388 0.143227,-0.\
134269 -0.05063,\
-0.193595 0.1508\
85,-0.673209 0.3\
7178,-0.884844 0\
.176821,-0.16940\
9 0.183569,-0.19\
3977 0.0992,-0.3\
63046 -0.265113,\
-0.531498 -0.519\
841,-3.04688 -0.\
475911,-4.69977 \
0.04068,-1.52104\
7 0.138873,-1.72\
3408 0.838024,-1\
.723408 0.470263\
,0 0.484237,0.03\
891 0.726427,2.0\
23493 0.119444,0\
.978978 0.289518\
,2.317111 0.3778\
57,2.973628 0.08\
839,0.656522 0.1\
60695,1.274172 0\
.160695,1.372551\
 0,0.11987 0.034\
93,0.178874 0.10\
5805,0.178874 0.\
169309,0 0.55563\
6,0.428693 0.555\
636,0.616525 0,0\
.178329 0.03111,\
0.191068 0.67842\
9,0.27632 0.5091\
22,0.06706 4.918\
22,1.715431 5.15\
0313,1.925458 0.\
189742,0.171701 \
0.224149,0.50882\
 0.08169,0.79984\
1 -0.174142,0.35\
5806 -0.35594,0.\
430626 -0.94938,\
0.390739 -0.3960\
9,-0.02661 -0.86\
9512,-0.159129 -\
2.348256,-0.6572\
34 -2.063474,-0.\
695093 -2.806555\
,-0.962397 -2.92\
2362,-1.051286 -\
0.05187,-0.03982\
 -0.102169,-0.01\
488 -0.149927,0.\
07432 -0.03924,0\
.07382 -0.218934\
,0.186479 -0.398\
77,0.250345 l -0\
.32694,0.116114 \
0.01388,5.624466\
 0.01388,5.62447\
1 3.505753,0.002\
4 c 3.870259,0.0\
024 3.8727,0.002\
4 4.181168,0.407\
057 0.13983,0.18\
3325 0.178544,0.\
308263 0.181176,\
0.584923 0.0048,\
0.417566 -0.1453\
33,0.663805 -0.5\
13571,0.846886 -\
0.234486,0.11659\
2 -0.965794,0.12\
1636 -19.178304,\
0.132293 -10.414\
039,0.0061 -20.1\
103125,-0.0038 -\
21.5473753,-0.02\
201 z\x22\x0a     id=\x22\
path870\x22\x0a     so\
dipodi:nodetypes\
=\x22sscsscccssssss\
sscsssssssssssss\
ssscsccccssssssc\
cssssssssssssscs\
sssssscsscssssss\
ssssssssssssssss\
sssscccsscssss\x22 \
/>\x0a</svg>\x0a\
"

qt_resource_name = b"\
\x00\x05\
\x00O\xa6S\
\x00I\
\x00c\x00o\x00n\x00s\
\x00\x05\
\x00o\xa6S\
\x00i\
\x00c\x00o\x00n\x00s\
\x00\x0e\
\x0dQ\x8b\x87\
\x00w\
\x00i\x00n\x00d\x00_\x00p\x00o\x00w\x00e\x00r\x00.\x00s\x00v\x00g\
"

qt_resource_struct = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x02\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x10\x00\x02\x00\x00\x00\x01\x00\x00\x00\x03\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00 \x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\
\x00\x00\x01\x89b\xc7*v\
"

def qInitResources():
    QtCore.qRegisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()

==> GridCal-5.1.11.tar.gz: GridCal-5.1.11/GridCal/Gui/WindPowerWizard/icons_rc.py <==
# Resource object code (Python 3)
# Created by: object code
# Created by: The Resource Compiler for Qt version 6.6.3
# WARNING! All changes made in this file will be lost!

from PySide6 import QtCore

qt_resource_data = b"\
\x00\x00\x1b\xfb\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<svg\x0a   wi\
dth=\x2248\x22\x0a   heig\
ht=\x2248\x22\x0a   viewB\
ox=\x220 0 48 48\x22\x0a \
  version=\x221.1\x22\x0a\
   id=\x22svg6\x22\x0a   \
sodipodi:docname\
=\x22wind_power.svg\
\x22\x0a   inkscape:ve\
rsion=\x221.1.2 (0a\
00cf5339, 2022-0\
2-04)\x22\x0a   xmlns:\
inkscape=\x22http:/\
/www.inkscape.or\
g/namespaces/ink\
scape\x22\x0a   xmlns:\
sodipodi=\x22http:/\
/sodipodi.source\
forge.net/DTD/so\
dipodi-0.dtd\x22\x0a  \
 xmlns=\x22http://w\
ww.w3.org/2000/s\
vg\x22\x0a   xmlns:svg\
=\x22http://www.w3.\
org/2000/svg\x22\x0a  \
 xmlns:rdf=\x22http\
://www.w3.org/19\
99/02/22-rdf-syn\
tax-ns#\x22\x0a   xmln\
s:cc=\x22http://cre\
ativecommons.org\
/ns#\x22\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22>\x0a  <metadat\
a\x0a     id=\x22metad\
ata12\x22>\x0a    <rdf\
:RDF>\x0a      <cc:\
Work\x0a         rd\
f:about=\x22\x22>\x0a    \
    <dc:format>i\
mage/svg+xml</dc\
:format>\x0a       \
 <dc:type\x0a      \
     rdf:resourc\
e=\x22http://purl.o\
rg/dc/dcmitype/S\
tillImage\x22 />\x0a  \
    </cc:Work>\x0a \
   </rdf:RDF>\x0a  \
</metadata>\x0a  <d\
efs\x0a     id=\x22def\
s10\x22>\x0a    <marke\
r\x0a       inkscap\
e:stockid=\x22Arrow\
1Lstart\x22\x0a       \
orient=\x22auto\x22\x0a  \
     refY=\x220.0\x22\x0a\
       refX=\x220.0\
\x22\x0a       id=\x22Arr\
ow1Lstart\x22\x0a     \
  style=\x22overflo\
w:visible\x22\x0a     \
  inkscape:issto\
ck=\x22true\x22>\x0a     \
 <path\x0a         \
id=\x22path4598\x22\x0a  \
       d=\x22M 0.0,\
0.0 L 5.0,-5.0 L\
 -12.5,0.0 L 5.0\
,5.0 L 0.0,0.0 z\
 \x22\x0a         styl\
e=\x22fill-rule:eve\
nodd;stroke:#000\
000;stroke-width\
:1.0pt\x22\x0a        \
 transform=\x22scal\
e(0.8) translate\
(12.5,0)\x22 />\x0a   \
 </marker>\x0a  </d\
efs>\x0a  <sodipodi\
:namedview\x0a     \
pagecolor=\x22#ffff\
ff\x22\x0a     borderc\
olor=\x22#666666\x22\x0a \
    borderopacit\
y=\x221\x22\x0a     objec\
ttolerance=\x2210\x22\x0a\
     gridtoleran\
ce=\x2210\x22\x0a     gui\
detolerance=\x2210\x22\
\x0a     inkscape:p\
ageopacity=\x220\x22\x0a \
    inkscape:pag\
eshadow=\x222\x22\x0a    \
 inkscape:window\
-width=\x222495\x22\x0a  \
   inkscape:wind\
ow-height=\x221016\x22\
\x0a     id=\x22namedv\
iew8\x22\x0a     showg\
rid=\x22false\x22\x0a    \
 inkscape:zoom=\x22\
3.0052038\x22\x0a     \
inkscape:cx=\x2266.\
21847\x22\x0a     inks\
cape:cy=\x22-22.793\
795\x22\x0a     inksca\
pe:window-x=\x2265\x22\
\x0a     inkscape:w\
indow-y=\x2227\x22\x0a   \
  inkscape:windo\
w-maximized=\x221\x22\x0a\
     inkscape:cu\
rrent-layer=\x22svg\
6\x22\x0a     inkscape\
:pagecheckerboar\
d=\x220\x22 />\x0a  <path\
\x0a     style=\x22fil\
l:#37c8ab;fill-o\
pacity:1;stroke-\
width:0.066147\x22\x0a\
     d=\x22M 4.8016\
926,44.487649 C \
2.4893281,44.458\
362 2.1648285,44\
.441422 1.979776\
2,44.340138 1.64\
58014,44.157407 \
1.4942949,43.916\
69 1.4945821,43.\
569206 c 0,-0.40\
9206 0.1916083,-\
0.710501 0.55242\
93,-0.870095 0.2\
665959,-0.117937\
 0.5131888,-0.12\
7024 3.9174436,-\
0.144328 l 3.632\
9018,-0.01847 v \
-5.409122 -5.409\
122 l -0.1984511\
,0.04072 c -0.93\
13392,0.191078 -\
3.381189,0.80561\
7 -3.9674033,0.9\
95225 -0.7743774\
,0.250464 -1.066\
6233,0.262002 -1\
.299482,0.05129 \
-0.2374048,-0.21\
4856 -0.1029823,\
-0.984423 0.2002\
7,-1.146735 0.07\
5418,-0.04034 0.\
3383773,-0.13548\
1 0.5843959,-0.2\
11373 0.2459708,\
-0.0759 0.566307\
2,-0.192575 0.71\
18319,-0.259283 \
1.0177639,-0.466\
56 2.4351586,-1.\
045491 2.7120432\
,-1.107716 0.181\
8939,-0.04087 0.\
4946214,-0.09272\
 0.6949392,-0.11\
5195 l 0.3641707\
,-0.04087 0.0988\
19,-0.308593 c 0\
.072499,-0.22625\
 0.1525115,-0.33\
5415 0.2998545,-\
0.409101 0.19897\
8,-0.0995 0.2001\
74,-0.10327 0.12\
0162,-0.379546 -\
0.188258,-0.6502\
63 -0.293394,-1.\
935168 -0.294686\
,-3.601539 0,-2.\
24132 0.05915,-2\
.507547 0.594254\
2,-2.597949 0.30\
9282,-0.05226 0.\
588702,0.05141 0\
.661919,0.245569\
 0.117195,0.3107\
18 0.579276,4.17\
9943 0.645746,5.\
406892 0.03876,0\
.717823 0.06211,\
0.839162 0.17892\
7,0.933756 0.103\
46,0.08378 0.140\
595,0.208017 0.1\
61843,0.541528 0\
.02728,0.430588 \
0.02871,0.433014\
 0.247358,0.4740\
34 0.266979,0.05\
009 4.237397,2.0\
4832 4.442022,2.\
235573 0.338712,\
0.310029 0.21816\
7,0.900694 -0.21\
2856,1.04295 -0.\
135092,0.0446 -0\
.353786,0.06625 \
-0.48596,0.04813\
 -0.39006,-0.053\
45 -2.817179,-1.\
046697 -3.936298\
,-1.610826 -0.40\
9967,-0.206659 -\
0.574538,-0.2634\
38 -0.545682,-0.\
188249 0.02249,0\
.05921 0.04115,2\
.508844 0.04115,\
5.443615 l 4.8e-\
5,5.335958 2.563\
168,0.01857 c 1.\
409738,0.01024 3\
.433829,-4.79e-4\
 4.497964,-0.024\
12 l 1.934794,-0\
.04269 v -8.1895\
11 -8.189515 l -\
0.227164,-0.0749\
6 c -0.203859,-0\
.06729 -0.58698,\
-0.417557 -0.740\
161,-0.67673 -0.\
03206,-0.05394 -\
0.251426,-0.1652\
03 -0.487922,-0.\
247244 -3.345537\
,-1.160662 -5.93\
5122,-2.115981 -\
6.191907,-2.2842\
12 -0.238219,-0.\
156091 -0.446241\
,-0.649339 -0.39\
3171,-0.932263 0\
.06513,-0.347091\
 0.318996,-0.598\
786 0.694844,-0.\
688957 0.38001,-\
0.09116 0.30842,\
-0.108376 2.6159\
99,0.629125 2.41\
104,0.978701 3.2\
87204,1.308684 4\
.413166,1.668538\
 l 0.340052,0.04\
159 c 0.286503,0\
.03503 0.355701,\
0.02168 0.439302\
,-0.08475 0.6227\
27,-0.792725 0.7\
63514,-0.970092 \
0.792753,-0.9984\
45 0.08197,-0.07\
957 1.403709,-1.\
538988 1.85708,-\
2.050554 0.69532\
2,-0.78459 1.745\
339,-2.038198 2.\
691035,-3.212771\
 0.889658,-1.104\
978 1.116774,-1.\
275665 1.581534,\
-1.188474 0.3663\
72,0.06873 0.602\
964,0.210812 0.7\
16426,0.430267 0\
.131647,0.254584\
 0.127627,0.6834\
73 -0.0091,0.948\
04 -0.155096,0.3\
00616 -0.830558,\
1.196141 -2.1169\
28,2.806684 -0.6\
12821,0.767252 -\
1.530953,1.92331\
5 -2.040313,2.56\
9017 -0.509313,0\
.645707 -0.99053\
5,1.237376 -1.06\
9351,1.314824 -0\
.126096,0.12388 \
-0.137772,0.1842\
72 -0.09724,0.50\
2144 0.06207,0.4\
87103 -0.01962,0\
.974398 -0.19467\
1,1.160714 l -0.\
14251,0.151674 0\
.121311,0.534761\
 c 0.07197,0.317\
461 0.02536,0.12\
2096 1.674659,4.\
618135 0.633542,\
1.727045 1.33652\
1,3.388401 1.400\
741,3.512664 0.3\
6063,0.697939 -0\
.357375,1.370703\
 -0.824816,0.737\
544 -0.425184,-0\
.575931 -1.38739\
,-2.765683 -3.41\
4974,-6.4171 -0.\
828644,-1.49222 \
0.110161,-2.3902\
38 0.107529,-2.2\
95817 -0.0048,0.\
115123 0.69336,3\
.902628 0.690345\
,9.181342 l -0.0\
048,6.787626 5.4\
07528,0.01259 c \
2.974141,0.0069 \
6.070119,-0.0083\
 6.879956,-0.033\
83 l 1.47238,-0.\
04642 v -5.47085\
9 c 0,-3.008969 \
-0.02106,-5.4899\
57 -0.0445,-5.51\
3301 -0.02345,-0\
.02335 -0.09585,\
0.04546 -0.16122\
1,0.152856 -0.19\
0652,0.313513 -0\
.854486,0.574031\
 -2.87695,1.1290\
54 -1.400024,0.3\
84207 -1.674324,\
0.406842 -1.8727\
76,0.154555 -0.2\
22474,-0.282862 \
-0.162417,-0.776\
033 0.121789,-0.\
999756 0.117483,\
-0.09249 1.05159\
7,-0.553238 2.79\
9043,-1.380581 1\
.135437,-0.53758\
 1.738306,-0.752\
723 2.109272,-0.\
752723 0.146625,\
0 0.172084,-0.02\
388 0.143227,-0.\
134269 -0.05063,\
-0.193595 0.1508\
85,-0.673209 0.3\
7178,-0.884844 0\
.176821,-0.16940\
9 0.183569,-0.19\
3977 0.0992,-0.3\
63046 -0.265113,\
-0.531498 -0.519\
841,-3.04688 -0.\
475911,-4.69977 \
0.04068,-1.52104\
7 0.138873,-1.72\
3408 0.838024,-1\
.723408 0.470263\
,0 0.484237,0.03\
891 0.726427,2.0\
23493 0.119444,0\
.978978 0.289518\
,2.317111 0.3778\
57,2.973628 0.08\
839,0.656522 0.1\
60695,1.274172 0\
.160695,1.372551\
 0,0.11987 0.034\
93,0.178874 0.10\
5805,0.178874 0.\
169309,0 0.55563\
6,0.428693 0.555\
636,0.616525 0,0\
.178329 0.03111,\
0.191068 0.67842\
9,0.27632 0.5091\
22,0.06706 4.918\
22,1.715431 5.15\
0313,1.925458 0.\
189742,0.171701 \
0.224149,0.50882\
 0.08169,0.79984\
1 -0.174142,0.35\
5806 -0.35594,0.\
430626 -0.94938,\
0.390739 -0.3960\
9,-0.02661 -0.86\
9512,-0.159129 -\
2.348256,-0.6572\
34 -2.063474,-0.\
695093 -2.806555\
,-0.962397 -2.92\
2362,-1.051286 -\
0.05187,-0.03982\
 -0.102169,-0.01\
488 -0.149927,0.\
07432 -0.03924,0\
.07382 -0.218934\
,0.186479 -0.398\
77,0.250345 l -0\
.32694,0.116114 \
0.01388,5.624466\
 0.01388,5.62447\
1 3.505753,0.002\
4 c 3.870259,0.0\
024 3.8727,0.002\
4 4.181168,0.407\
057 0.13983,0.18\
3325 0.178544,0.\
308263 0.181176,\
0.584923 0.0048,\
0.417566 -0.1453\
33,0.663805 -0.5\
13571,0.846886 -\
0.234486,0.11659\
2 -0.965794,0.12\
1636 -19.178304,\
0.132293 -10.414\
039,0.0061 -20.1\
103125,-0.0038 -\
21.5473753,-0.02\
201 z\x22\x0a     id=\x22\
path870\x22\x0a     so\
dipodi:nodetypes\
=\x22sscsscccssssss\
sscsssssssssssss\
ssscsccccssssssc\
cssssssssssssscs\
sssssscsscssssss\
ssssssssssssssss\
sssscccsscssss\x22 \
/>\x0a</svg>\x0a\
"

qt_resource_name = b"\
\x00\x05\
\x00O\xa6S\
\x00I\
\x00c\x00o\x00n\x00s\
\x00\x05\
\x00o\xa6S\
\x00i\
\x00c\x00o\x00n\x00s\
\x00\x0e\
\x0dQ\x8b\x87\
\x00w\
\x00i\x00n\x00d\x00_\x00p\x00o\x00w\x00e\x00r\x00.\x00s\x00v\x00g\
"

qt_resource_struct = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x02\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x10\x00\x02\x00\x00\x00\x01\x00\x00\x00\x03\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00 \x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\
\x00\x00\x01\x8b\xd7}+\x92\
"

def qInitResources():
    QtCore.qRegisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()
